package betterquesting.api.utils;

import betterquesting.api.api.QuestingAPI;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonPrimitive;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagByte;
import net.minecraft.nbt.NBTTagByteArray;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagDouble;
import net.minecraft.nbt.NBTTagFloat;
import net.minecraft.nbt.NBTTagInt;
import net.minecraft.nbt.NBTTagIntArray;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.nbt.NBTTagLong;
import net.minecraft.nbt.NBTTagShort;
import net.minecraft.nbt.NBTTagString;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_api_utils.jar:betterquesting/api/utils/NBTConverter.class */
public class NBTConverter {
    private static Field f_tagList;

    private static JsonElement NBTtoJSON_Base(NBTBase tag, boolean format) {
        if (tag == null) {
            return new JsonObject();
        }
        if (tag.func_74732_a() >= 1 && tag.func_74732_a() <= 6) {
            return new JsonPrimitive(getNumber(tag));
        }
        if (tag instanceof NBTTagString) {
            return new JsonPrimitive(((NBTTagString) tag).func_150285_a_());
        }
        if (tag instanceof NBTTagCompound) {
            return NBTtoJSON_Compound((NBTTagCompound) tag, new JsonObject(), format);
        }
        if (tag instanceof NBTTagList) {
            if (format) {
                JsonObject jAry = new JsonObject();
                List<NBTBase> tagList = getTagList((NBTTagList) tag);
                for (int i = 0; i < tagList.size(); i++) {
                    jAry.add(i + ":" + ((int) tagList.get(i).func_74732_a()), NBTtoJSON_Base(tagList.get(i), true));
                }
                return jAry;
            }
            JsonArray jAry2 = new JsonArray();
            for (NBTBase t : getTagList((NBTTagList) tag)) {
                jAry2.add(NBTtoJSON_Base(t, false));
            }
            return jAry2;
        }
        if (tag instanceof NBTTagByteArray) {
            JsonArray jAry3 = new JsonArray();
            for (byte b : ((NBTTagByteArray) tag).func_150292_c()) {
                jAry3.add(new JsonPrimitive(Byte.valueOf(b)));
            }
            return jAry3;
        }
        if (tag instanceof NBTTagIntArray) {
            JsonArray jAry4 = new JsonArray();
            for (int i2 : ((NBTTagIntArray) tag).func_150302_c()) {
                jAry4.add(new JsonPrimitive(Integer.valueOf(i2)));
            }
            return jAry4;
        }
        return new JsonObject();
    }

    public static JsonObject NBTtoJSON_Compound(NBTTagCompound parent, JsonObject jObj, boolean format) {
        if (parent == null) {
            return jObj;
        }
        for (String key : parent.func_150296_c()) {
            NBTBase tag = parent.func_74781_a(key);
            if (format) {
                jObj.add(key + ":" + ((int) tag.func_74732_a()), NBTtoJSON_Base(tag, true));
            } else {
                jObj.add(key, NBTtoJSON_Base(tag, false));
            }
        }
        return jObj;
    }

    public static NBTTagCompound JSONtoNBT_Object(JsonObject jObj, NBTTagCompound tags, boolean format) {
        if (jObj == null) {
            return tags;
        }
        for (Map.Entry<String, JsonElement> entry : jObj.entrySet()) {
            String key = entry.getKey();
            if (!format) {
                tags.func_74782_a(key, JSONtoNBT_Element(entry.getValue(), (byte) 0, false));
            } else {
                String[] s = key.split(":");
                byte id = 0;
                try {
                    id = Byte.parseByte(s[s.length - 1]);
                    key = key.substring(0, key.lastIndexOf(":" + ((int) id)));
                } catch (Exception e) {
                    if (tags.func_74764_b(key)) {
                        QuestingAPI.getLogger().log(Level.WARN, "JSON/NBT formatting conflict on key '" + key + "'. Skipping...");
                    }
                }
                tags.func_74782_a(key, JSONtoNBT_Element(entry.getValue(), id, true));
            }
        }
        return tags;
    }

    /* JADX WARN: Code restructure failed: missing block: B:22:0x0029, code lost:
    
        if (r5.getAsJsonPrimitive().isBoolean() != false) goto L17;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private static net.minecraft.nbt.NBTBase JSONtoNBT_Element(com.google.gson.JsonElement r5, byte r6, boolean r7) {
        /*
            Method dump skipped, instructions count: 556
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: betterquesting.api.utils.NBTConverter.JSONtoNBT_Element(com.google.gson.JsonElement, byte, boolean):net.minecraft.nbt.NBTBase");
    }

    public static List<NBTBase> getTagList(NBTTagList tag) {
        try {
            return (ArrayList) f_tagList.get(tag);
        } catch (IllegalAccessException e) {
            return Collections.emptyList();
        }
    }

    public static Number getNumber(NBTBase tag) {
        if (tag instanceof NBTTagByte) {
            return Byte.valueOf(((NBTTagByte) tag).func_150290_f());
        }
        if (tag instanceof NBTTagShort) {
            return Short.valueOf(((NBTTagShort) tag).func_150289_e());
        }
        if (tag instanceof NBTTagInt) {
            return Integer.valueOf(((NBTTagInt) tag).func_150287_d());
        }
        if (tag instanceof NBTTagFloat) {
            return Float.valueOf(((NBTTagFloat) tag).func_150288_h());
        }
        if (tag instanceof NBTTagDouble) {
            return Double.valueOf(((NBTTagDouble) tag).func_150286_g());
        }
        if (tag instanceof NBTTagLong) {
            return Long.valueOf(((NBTTagLong) tag).func_150291_c());
        }
        return 0;
    }

    public static NBTBase instanceNumber(Number num, byte type) {
        switch (type) {
            case 1:
                return new NBTTagByte(num.byteValue());
            case 2:
                return new NBTTagShort(num.shortValue());
            case 3:
                return new NBTTagInt(num.intValue());
            case 4:
                return new NBTTagLong(num.longValue());
            case 5:
                return new NBTTagFloat(num.floatValue());
            default:
                return new NBTTagDouble(num.doubleValue());
        }
    }

    private static byte fallbackTagID(JsonElement jObj) {
        byte tagID;
        byte tagID2 = 0;
        if (jObj.isJsonPrimitive()) {
            JsonPrimitive prim = jObj.getAsJsonPrimitive();
            if (prim.isNumber()) {
                if (prim.getAsString().contains(".")) {
                    tagID = 6;
                } else {
                    tagID = 4;
                }
            } else if (prim.isBoolean()) {
                tagID = 1;
            } else {
                tagID = 8;
            }
        } else if (jObj.isJsonArray()) {
            JsonArray array = jObj.getAsJsonArray();
            Iterator it = array.iterator();
            while (it.hasNext()) {
                JsonElement entry = (JsonElement) it.next();
                if (entry.isJsonPrimitive() && tagID2 == 0) {
                    try {
                        Iterator it2 = array.iterator();
                        while (it2.hasNext()) {
                            JsonElement element = (JsonElement) it2.next();
                            if (element.getAsLong() != element.getAsByte()) {
                                throw new ClassCastException();
                                break;
                            }
                        }
                        tagID2 = 7;
                    } catch (Exception e) {
                        try {
                            Iterator it3 = array.iterator();
                            while (it3.hasNext()) {
                                JsonElement element2 = (JsonElement) it3.next();
                                if (element2.getAsLong() != element2.getAsInt()) {
                                    throw new ClassCastException();
                                    break;
                                }
                            }
                            tagID2 = 11;
                        } catch (Exception e2) {
                            tagID2 = 9;
                        }
                    }
                } else if (!entry.isJsonPrimitive()) {
                    break;
                }
            }
            tagID = 9;
        } else {
            tagID = 10;
        }
        return tagID;
    }

    static {
        try {
            f_tagList = NBTTagList.class.getDeclaredField("field_74747_a");
            f_tagList.setAccessible(true);
        } catch (Exception e) {
            try {
                f_tagList = NBTTagList.class.getDeclaredField("tagList");
                f_tagList.setAccessible(true);
            } catch (Exception e2) {
                QuestingAPI.getLogger().log(Level.ERROR, "Unable to hook into NBTTagList!", e2);
            }
        }
    }
}
